@@ -1,3 +1,20 @@
+# -*- coding: utf-8 -*-
+
+#
+# penguin_py - A lightweight, customizable stopwatch  decorator
+#
+# Andres Espitia
+# espitiaandres.com
+# espitiaandres123@gmail.com
+#
+# License: MIT
+#
+
+
+# Colours are ANSI escape sequences for the terminal to show them.
+
+
+# Foreground colours are for the **text**
 foreground_colours = {
     "red": "\033[91m",
     "yellow": "\033[93m",
@@ -8,6 +25,7 @@ foreground_colours = {
     "grey": "\033[37m",
 }
 
+# Background colours are for the **text's highlight**
 background_colours = {
     "red": "\033[41m",
     "yellow": "\033[43m",
@@ -21,6 +39,6 @@ background_colours = {
 }
 
 colour_map = {
-    "foreground_colours": foreground_colours,
-    "background_colours": background_colours,
+    "foreground": foreground_colours,
+    "background": background_colours,
 }
