@@ -1,3 +1,15 @@
+# -*- coding: utf-8 -*-
+
+#
+# penguin_py - A lightweight, customizable stopwatch  decorator
+#
+# Andres Espitia
+# espitiaandres.com
+# espitiaandres123@gmail.com
+#
+# License: MIT
+#
+
 import logging
 import time
 import traceback
@@ -18,10 +30,7 @@ logger = logging.getLogger("penguin")
 
 """
 TODO:
-- Update README.md and README_PYPI.md
-    - Show async decorator
-    - If the function throws an error, the logs won't show up
-    - Make more appealing, center the images
+- reddit post
 
 """
 
